# New in 0.14.5 (2021-11-22)

Bug fixes, new tutorials.

## Changes

-   Fix `kl_weight` floor for Pytorch-based models ([#1269]).
-   Add support for more Pyro guides ([#1267]).
-   Update scArches, harmonization tutorials, add basic R tutorial, tabula muris label transfer tutorial ([#1274]).

## Contributors

-   [@adamgayoso]
-   [@jjhong922]
-   [@watiss]
-   [@vitkl]

[#1267]: https://github.com/YosefLab/scvi-tools/pull/1267
[#1269]: https://github.com/YosefLab/scvi-tools/pull/1269
[#1274]: https://github.com/YosefLab/scvi-tools/pull/1274
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@vitkl]: https://github.com/vitkl
[@watiss]: https://github.com/watiss
